## servicecatalog-puppet

![logo](./docs/logo.png) 

This is a framework where you list your AWS accounts with tags and your AWS Service Catalog products with tags or target
accounts. The framework works through your lists, dedupes and spots collisions and then provisions the products into your 
AWS accounts for you. It handles the Portfolio sharing, its acceptance and can provision products cross account and cross 
region.

Read the docs here: https://aws-service-catalog-puppet.readthedocs.io/en/latest/


## License

This library is licensed under the Apache 2.0 License. 
